package com.persagy.apm.energy.report.monthly.outline.service.impl;

import com.persagy.apm.energy.report.monthly.detail.business.model.OpenCost;
import com.persagy.apm.energy.report.monthly.detail.business.model.OpenPower;
import com.persagy.apm.energy.report.monthly.detail.business.model.Platform;
import com.persagy.apm.energy.report.monthly.detail.business.model.dto.AddReportBusinessDetailDTO;
import com.persagy.apm.energy.report.monthly.detail.business.service.IReportBusinessDetailService;
import com.persagy.apm.energy.report.monthly.outline.constants.BusinessReportParagraphs;
import com.persagy.apm.energy.report.monthly.outline.constants.enums.ReportStateEnum;
import com.persagy.apm.energy.report.monthly.outline.model.ReportOutline;
import com.persagy.apm.energy.report.monthly.outline.service.IBusinessReportCostInfoService;
import com.persagy.apm.energy.report.monthly.outline.service.IBusinessReportPlatformInfoService;
import com.persagy.apm.energy.report.monthly.outline.service.IBusinessReportPowerInfoService;
import com.persagy.apm.energy.report.monthly.outline.service.IReportOutlineService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * 商业项目报告生成类
 *
 * @author lixing
 * @version V1.0 2021/5/12 2:53 下午
 **/
@Component
@Slf4j
public class BusinessProjectReportGenerator {
    @Autowired
    private IReportBusinessDetailService businessDetailService;
    @Autowired
    private IBusinessReportPowerInfoService businessReportPowerInfoService;
    @Autowired
    private IBusinessReportCostInfoService businessReportCostInfoService;
    @Autowired
    private IBusinessReportPlatformInfoService businessReportPlatformInfoService;
    @Autowired
    private IReportOutlineService reportOutlineService;


    /**
     * 生成报告
     *
     * @param reportOutline 报告outline对象
     * @author lixing
     * @version V1.0 2021/5/24 4:09 下午
     */
    public void generateReport(ReportOutline reportOutline) {
        try {
            AddReportBusinessDetailDTO addReportBusinessDetailDTO = new AddReportBusinessDetailDTO();
            // 获取在营项目用电量下拥有的信息点分组和信息点
            List<String> powerGroupIdList = businessDetailService.getGroupsByParagraph(
                    reportOutline.getReportTypeId(), BusinessReportParagraphs.OPEN_POWER);
            List<String> powerFunctionIdList = businessDetailService.getFunctionsByParagraph(
                    reportOutline.getReportTypeId(), BusinessReportParagraphs.OPEN_POWER);
            OpenPower openPower = (OpenPower)businessReportPowerInfoService.getPowerInfo(reportOutline, powerGroupIdList, powerFunctionIdList);
            addReportBusinessDetailDTO.setOpenPower(openPower);

            List<String> costGroupIdList = businessDetailService.getGroupsByParagraph(
                    reportOutline.getReportTypeId(), BusinessReportParagraphs.OPEN_COST);
            List<String> costFunctionIdList = businessDetailService.getFunctionsByParagraph(
                    reportOutline.getReportTypeId(), BusinessReportParagraphs.OPEN_COST);
            OpenCost openCost = (OpenCost)businessReportCostInfoService.getOpenCost(reportOutline, costGroupIdList, costFunctionIdList);
            addReportBusinessDetailDTO.setOpenCost(openCost);

            List<Platform> platforms = businessReportPlatformInfoService.getPlatforms(reportOutline);
            addReportBusinessDetailDTO.setPlatform(platforms);

            businessDetailService.createReportBusinessDetail(addReportBusinessDetailDTO);
        } catch (Exception e) {
            log.error("生成报告失败", e);
            reportOutline.setStatus(ReportStateEnum.BUILD_FAILED.getType());
            reportOutlineService.updateReportOutline(reportOutline);
        }
    }

}
