package com.persagy.apm.energy.report.saasweb.service.impl;

import com.alibaba.fastjson.JSON;
import com.persagy.apm.common.model.dto.PoemsFeignBaseDTO;
import com.persagy.apm.common.response.PoemsFeignResponse;
import com.persagy.apm.energy.report.saasweb.client.SaasWebClient;
import com.persagy.apm.energy.report.saasweb.model.dto.QueryByProjectIdDTO;
import com.persagy.apm.energy.report.saasweb.model.dto.QueryPartitionDTO;
import com.persagy.apm.energy.report.saasweb.model.dto.QueryProjectDTO;
import com.persagy.apm.energy.report.saasweb.model.vo.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 运维平台feign客户端包装类
 *
 * @author lixing
 * @version V1.0 2021/3/22 2:13 下午
 **/
@Service
public class SaasWebClientWrapper {
    @Autowired
    private SaasWebClient saasWebClient;

    /**
     * 根据项目id，获取项目信息
     *
     * @param queryByProjectIdDTO 查询条件
     * @return 项目下的建筑信息
     * @author lixing
     * @version V1.0 2021/5/19 2:27 下午
     */
    public PoemsFeignResponse<SimpleProjectVO> getProjectById(QueryByProjectIdDTO queryByProjectIdDTO) {
        return saasWebClient.getProjectById(JSON.toJSONString(queryByProjectIdDTO));
    }

    /**
     * 根据项目id，加载项目下的建筑信息
     *
     * @param queryByProjectIdDTO 查询条件
     * @return 项目下的建筑信息
     * @author lixing
     * @version V1.0 2021/5/19 2:27 下午
     */
    public PoemsFeignResponse<BuildingInfoVO> listBuildingsByProjectId(QueryByProjectIdDTO queryByProjectIdDTO){
        return saasWebClient.listBuildingsByProjectId(JSON.toJSONString(queryByProjectIdDTO));
    }

    /**
     * 查询项目列表
     *
     * @param queryProjectDTO 查询条件
     * @return 项目列表
     * @author lixing
     * @version V1.0 2021/5/19 2:27 下午
     */
    public PoemsFeignResponse<PoemsProjectVO> queryProjects(QueryProjectDTO queryProjectDTO){
        return saasWebClient.queryProjects(JSON.toJSONString(queryProjectDTO));
    }

    /**
     * 根据id查询管理分区
     *
     * @param queryPartitionDTO 查询条件
     * @return 项目列表
     * @author lixing
     * @version V1.0 2021/5/19 2:27 下午
     */
    public PoemsFeignResponse<PoemsPartitionVO> queryPartitionsByIds(QueryPartitionDTO queryPartitionDTO){
        return saasWebClient.queryPartitionsByIds(JSON.toJSONString(queryPartitionDTO));
    }

    /**
     * 获取用户信息（基本信息和关联的项目）
     *
     * @param poemsFeignBaseDTO 登录信息
     * @return 用户信息
     * @author lixing
     * @version V1.0 2021/5/19 3:36 下午
     */
    public PoemsFeignResponse<UserProjectsInfoVO> getCurrentUserProjectsInfo(PoemsFeignBaseDTO poemsFeignBaseDTO){
        return saasWebClient.getCurrentUserProjectsInfo(JSON.toJSONString(poemsFeignBaseDTO));
    }

    /**
     * 获取用户信息（基本信息和关联的分区项目树）
     *
     * @param poemsFeignBaseDTO 登录信息
     * @return 用户信息
     * @author lixing
     * @version V1.0 2021/5/19 3:36 下午
     */
    public PoemsFeignResponse<UserPartitionProjectsInfoVO> getCurrentUserPartitionProjectsInfo(PoemsFeignBaseDTO poemsFeignBaseDTO){
        return saasWebClient.getCurrentUserPartitionProjectsInfo(JSON.toJSONString(poemsFeignBaseDTO));
    }

    /**
     * 获取所有项目功能类型
     *
     * @param poemsFeignBaseDTO 登录信息
     * @return 所有项目功能类型树
     * @author lixing
     * @version V1.0 2021/5/19 3:36 下午
     */
    public PoemsFeignResponse<FunctionTypeVO> getAllProjectFunctionTypes(PoemsFeignBaseDTO poemsFeignBaseDTO){
        return saasWebClient.getAllProjectFunctionTypes(JSON.toJSONString(poemsFeignBaseDTO));
    }
}
